Index: server/lib/ippattribute.py
===================================================================
--- server/lib/ippattribute.py	(revision 264657160e09a00f9f620f27cb7e6f672f4a9882)
+++ server/lib/ippattribute.py	(revision ebf327dd25c74049a9010d04d52f522d8598cd18)
@@ -2,10 +2,10 @@
 
 import sys, struct, logging
-from ippvalue import IPPValue
+from ippvalue import Value
 
 # initialize logger
 logger = logging.getLogger("ippLogger")
 
-class IPPAttribute():
+class Attribute():
     """
     In addition to what the RFC reports, an attribute has an
@@ -42,5 +42,5 @@
     def __init__(self, name, values):
         """
-        Initialize an IPPAttribute.
+        Initialize an Attribute.
         
         Arguments:
@@ -48,5 +48,5 @@
             name -- the name of the attribute
 
-            values -- a list of IPPValues.  May not be empty.
+            values -- a list of Values.  May not be empty.
         """
 
@@ -56,6 +56,6 @@
         # make sure the list of values isn't empty
         assert len(values) > 0
-        # make sure each value is an IPPValue
-        for value in values: assert isinstance(value, IPPValue)
+        # make sure each value is a Value
+        for value in values: assert isinstance(value, Value)
          
         self.name = name
Index: server/lib/ipprequest.py
===================================================================
--- server/lib/ipprequest.py	(revision 264657160e09a00f9f620f27cb7e6f672f4a9882)
+++ server/lib/ipprequest.py	(revision ebf327dd25c74049a9010d04d52f522d8598cd18)
@@ -2,12 +2,12 @@
 
 import sys, struct, logging
-from ippattributegroup import IPPAttributeGroup
-from ippattribute import IPPAttribute
-from ippvalue import IPPValue
+from ippattributegroup import AttributeGroup
+from ippattribute import Attribute
+from ippvalue import Value
 
 # initialize logger
 logger = logging.getLogger("ippLogger")
 
-class IPPRequest():
+class Request():
     """
     From RFC 2565:
@@ -39,8 +39,7 @@
                  attribute_groups=[], data=None, request=None, length=sys.maxint):
         """
-        Create an IPPRequest.  Takes either the segments of the
-        request separately, or a file handle for the request to parse.
-        If the file handle is passed in, all other arguments are
-        ignored.
+        Create a Request.  Takes either the segments of the request
+        separately, or a file handle for the request to parse.  If the
+        file handle is passed in, all other arguments are ignored.
 
         Keyword arguments for passing in the segments of the request:
@@ -56,5 +55,5 @@
                           request itself.
 
-            attribute_groups -- a list of IPPAttributes, at least length 1
+            attribute_groups -- a list of Attributes, at least length 1
 
             data -- (optional) variable length, containing the actual
@@ -77,7 +76,7 @@
             # make sure the request id isn't empty
             assert request_id is not None
-            # make sure attribute_groups is a list of IPPAttributes
+            # make sure attribute_groups is a list of Attributes
             assert len(attribute_groups) > 0
-            for a in attribute_groups: assert isinstance(a, IPPAttributeGroup)
+            for a in attribute_groups: assert isinstance(a, AttributeGroup)
             
         # if the request isn't None, then we'll read directly from
@@ -148,10 +147,10 @@
                         length -= value_length
                         
-                        ippvalue = IPPValue(value_tag, value)
+                        ippvalue = Value(value_tag, value)
                         logger.debug("value : %s" % ippvalue.value)
 
-                        # create a new IPPAttribute from the data we just
+                        # create a new Attribute from the data we just
                         # read in, and add it to our attributes list
-                        attributes.append(IPPAttribute(name, [ippvalue]))
+                        attributes.append(Attribute(name, [ippvalue]))
 
                     else:
@@ -165,5 +164,5 @@
                         length -= value_length
 
-                        ippvalue = IPPValue(value_tag, value)
+                        ippvalue = Value(value_tag, value)
                         logger.debug("value : %s" % ippvalue.value)
 
@@ -175,5 +174,6 @@
                     length -= 1
 
-                self.attribute_groups.append(IPPAttributeGroup(attribute_group_tag, attributes))
+                self.attribute_groups.append(AttributeGroup(
+                    attribute_group_tag, attributes))
 
             # once we hit the end-of-attributes tag, the only thing
Index: server/lib/ippvalue.py
===================================================================
--- server/lib/ippvalue.py	(revision 264657160e09a00f9f620f27cb7e6f672f4a9882)
+++ server/lib/ippvalue.py	(revision ebf327dd25c74049a9010d04d52f522d8598cd18)
@@ -7,5 +7,5 @@
 logger = logging.getLogger("ippLogger")
 
-class IPPValue():
+class Value():
     """
     An IPP value consists of a tag and a value, and optionally, a name.
@@ -27,5 +27,5 @@
     def __init__(self, value_tag, value, unpack=True):
         """
-        Initialize an IPPValue:
+        Initialize a Value:
 
         Arguments:

Index: server/lib/ippattributegroup.py
===================================================================
--- server/lib/ippattributegroup.py	(revision 264657160e09a00f9f620f27cb7e6f672f4a9882)
+++ server/lib/ippattributegroup.py	(revision ebf327dd25c74049a9010d04d52f522d8598cd18)
@@ -2,18 +2,18 @@
 
 import sys, struct, logging
-from ippattribute import IPPAttribute
+from ippattribute import Attribute
 
 # initialize logger
 logger = logging.getLogger("ippLogger")
 
-class IPPAttributeGroup():
+class AttributeGroup():
     """
-    An IPPAttributeGroup consists of an attribute-group-tag, followed
-    by a sequence of IPPAttributes.
+    An AttributeGroup consists of an attribute-group-tag, followed by
+    a sequence of Attributes.
     """
 
     def __init__(self, attribute_group_tag, attributes=[]):
         """
-        Initialize an IPPAttributeGroup.
+        Initialize an AttributeGroup.
 
         Arguments:
@@ -28,7 +28,7 @@
         assert attribute_group_tag is not None
 
-        # make sure attributes is a list or tuple of IPPAttributes
+        # make sure attributes is a list or tuple of Attributes
         assert isinstance(attributes, (list, tuple))
-        for a in attributes: assert isinstance(a, IPPAttribute)
+        for a in attributes: assert isinstance(a, Attribute)
 
         self.attribute_group_tag = attribute_group_tag
@@ -40,5 +40,5 @@
     def toBinaryData(self):
         """
         Convert the IPPAttributeGroup to binary.
         """
 
@@ -40,5 +40,5 @@
     def toBinaryData(self):
         """
-        Convert the IPPAttributeGroup to binary.
+        Convert the AttributeGroup to binary.
         """
 